/* meko
 * Copyright (C) 2001 Scott James Remnant <scott@netsplit.com>.
 * All Rights Reserved.
 *
 * image-widget.c
 *  - Image widget creation
 * -- 
 * $Id: image-widget.c,v 1.1 2001/09/17 10:31:02 scott Exp $
 * 
 * This file is distributed according to the GNU General Public
 * License.  For full details, read the top of 'main.c' or the
 * file called COPYING that was distributed with this code.
 */

#include <meko.h>

#include <glib.h>
#include <gdk/gdk.h>
#include <gtk/gtkobject.h>
#include <gtk/gtkwidget.h>
#include <gtk/gtkalignment.h>
#include <libgnome/gnome-defs.h>
#include <libgnome/gnome-util.h>
#include <libgnomeui/gnome-canvas.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <gdk-pixbuf/gnome-canvas-pixbuf.h>

#include "image-widget.h"

/* meko_create_image_widget
 * Create a widget containing an arbitrary image from the Meko art directory.
 * Actually returns it inside a Canvas, so it's antialiased and pretty.
 * The strange paramets are because this is mostly used from Glade.
 */
GtkWidget *
meko_create_image_widget(gchar *name, gchar *string1, gchar *string2,
			 gint int1, gint int2)
{
	GdkPixbuf *pixbuf;
	gchar	  *filename;
	double	   width, height;
	GtkWidget *canvas, *align;

	if (!string1)
		return NULL;

	/* Load the pixbuf from the MEKO_IMAGESDIR directory */
	filename = g_concat_dir_and_file(MEKO_IMAGESDIR, string1);
	pixbuf = gdk_pixbuf_new_from_file(filename);
	g_free(filename);
	
	/* Make a canvas */
	gdk_rgb_init();
 	canvas = gnome_canvas_new_aa();
	GTK_OBJECT_UNSET_FLAGS(GTK_WIDGET(canvas), GTK_CAN_FOCUS);

	/* If we didn't find the image, just make a blank canvas */
	if (pixbuf) {
		/* Put the image in the canvas */
		gnome_canvas_item_new(gnome_canvas_root(GNOME_CANVAS(canvas)),
				      GNOME_TYPE_CANVAS_PIXBUF,
				      "pixbuf", pixbuf,
				      NULL);

		/* Set the canvas size to the image size */
		width = gdk_pixbuf_get_width(pixbuf);
		height = gdk_pixbuf_get_height(pixbuf);
		gtk_widget_set_usize(canvas, width, height);

		/* set the scroll region */
		gnome_canvas_set_scroll_region(GNOME_CANVAS(canvas), 0.0, 0.0,
					       width, height);

		/* Don't need the pixbuf anymore */
		gdk_pixbuf_unref(pixbuf);
	}

	/* Canvas goes in an alignment */
	align = gtk_widget_new(GTK_TYPE_ALIGNMENT,
			       "child", canvas,
			       "xalign", 0.00,
			       "yalign", 0.00,
			       "xscale", 0.00,
			       "yscale", 0.00,
			       NULL);

	/* Show and return */
	gtk_widget_show(canvas);
	gtk_widget_show(align);
	
	return align;
}
